@@ -1,12 +1,13 @@
-import Yi
-import Yi.Keymap.Emacs as Emacs
-import Yi.String (mapLines)
+import           Yi
+import qualified Yi.Rope as R
+import           Yi.Keymap.Emacs as Emacs
+import           Yi.String (mapLines)
 
 increaseIndent :: BufferM ()
 increaseIndent = do
    r <- getSelectRegionB
    r' <- unitWiseRegion Line r -- extend the region to full lines.
-   modifyRegionB (mapLines (' ':)) r'
+   modifyRegionB (mapLines (R.cons ' ')) r'
 
 
 main :: IO ()
@@ -14,7 +15,7 @@ main = yi $ defaultEmacsConfig
   { defaultKm =
       Emacs.mkKeymap $ override Emacs.defKeymap $ \parent _self ->
         parent {
-           eKeymap = (eKeymap parent) ||> (metaCh '>' ?>>! increaseIndent)
+           _eKeymap = (_eKeymap parent) ||> (metaCh '>' ?>>! increaseIndent)
         }
       -- bind M-> to increaseIndent and mix with default Emacs keymap.
   }
